default_resources = {
        "chosen":{None:{'js':("jquery_chosen/chosen.jquery.js",),
                        'css':("jquery_chosen/chosen.css",)}
                 },
        "foundation":{None:{'css':'deform_foundation.css'}},
        }
